#!/bin/ksh
DEBUG=FALSE
if [ ${DEBUG} = TRUE ]; then
    set -x
fi

#####################################################################
#
# Header
#
# Licensed Materials - Property of IBM Corp.
# (C) Copyright IBM Corp. 2004
# 
# All Rights Reserved
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.

    SCRIPT_VER=01.05
    SCRIPT_DATE=01/25/2006
    SCRIPT_SCCS=

#####################################################################
#
# History
#
# DATE        Ver    Auth         Abstract
# ----------  -----  -----------  ----------------------------------
# 11/15/2004  00.01  brookh       initial design 
# 11/18/2004  01.00  brookh       add "-v" option
# 11/26/2004  01.01  brookh       Check server status before stop/start
# 11/26/2004  01.02  brookh       .pid file is not reliable immediately after 
#                                  start/stop, so only check before first start
# 01/12/2006  01.03  mmarkand     add parsing routine for command line arguments
# 01/20/2006  01.04  mmarkand     added option -u to only un-deploy an application
# 01/24/2006  01.05  mmarkand     added -conntype NONE and a warning message in uninstall
#
# 
#####################################################################
#
# Usage: ./deploy_IDSWebApp.sh [-v] [-h] [-w IDSWebApp.war file] 
#                                       [-a Application Name] [-u] 
#
# Deploys IDSWebApp.war to WAS, retaining the configuration settings of the 
# currently deployed IDSWebApp, if any.
#
# NOTE:   When deploying the application deploy_IDSWebApp.sh must be copied 
#         to WAS_HOME/bin. 
#
# {-h     Display Usage. }
#
# {-v     Display the version and date strings for the deploy_IDSWebApp
#        script and the application war file.}
#
# {-w     The fully qualified path of the IDSWebApp.war file to deploy.  }
#
# {-a     Application Name. Defaults to IDSWebApp.war if not specified. }
#
# {-u     Uninstall a previously existing application.
#        -a option should be used to specify the application to uninstall
#        If not specified default application IDSWebApp.war would be un-deployed.}
#
#
#####################################################################
#
# Set QualifiedPath of $1, or return error and clear QualifiedPath
#
QualifiedPath=
QualifyPath()
{
    if [ ${DEBUG} = TRUE ]; then
        set -x
    fi

    if [ -n $1 ]; then
        QualifiedPath=
        save_PWD=$(pwd)
        cd $(dirname ${1}) || return $?
        QualifiedPath=$(pwd)/$(basename ${1})
        cd ${save_PWD}
    else 
        QualifiedPath=$(pwd)
    fi
}

#####################################################################
#
# Print localized "File not found" error and return failure RC
#
AssertFileExists()
{
    if [ ${DEBUG} = TRUE ]; then
        set -x
    fi
    
    if [ ! -f $1 ]; then
        ls $1 >/dev/null
    fi
}

#####################################################################
#
# Echo cmd and then call it
#
EchoCmd()
{
    if [ ${DEBUG} = TRUE ]; then
        set -x
    fi
    
    echo ""
    echo "$*"    
    eval $*
}

#####################################################################
#
PATCH_SCRIPT=
WAS_SERVER=server1
WAS_TEMP=
UNINSTALL_TEMP=
APP_ROOT=
IDSWebApp=
OPTION_V=FALSE
IDSWebApp_Name= 
IDSWebAppInfo=WEB-INF/classes/IDSConfig/IDSWebAppInfo/IDSWebAppInfo.xml
CONFIG_FILES="\
    WEB-INF/classes/security/console_passwd \
    WEB-INF/classes/IDSConfig/IDSServersConfig/IDSServersInfo.xml \
    WEB-INF/classes/IDSConfig/IDSAppReg/IDSAppReg.xml \
    WEB-INF/classes/IDSConfig/IDSSessionConfig/IDSSessionMgmt.xml \
    "
    
InitGlobalVariables()
{
    if [ ${DEBUG} = TRUE ]; then
        set -x
    fi

    QualifyPath $0 || return $?
    PATCH_SCRIPT=${QualifiedPath}
    PATCH_DIR=$(dirname ${PATCH_SCRIPT})

    AssertFileExists "${PATCH_DIR}/setupCmdLine.sh" || return $?
    . "${PATCH_DIR}/setupCmdLine.sh" || return $?

    WAS_TEMP="${WAS_HOME}/temp/deploy_IDSWebApp.tmp" 
    UNINSTALL_TEMP="${WAS_HOME}/temp/uninstall_IDSWebApp.tmp"
    APP_ROOT="${WAS_HOME}/installedApps/${WAS_NODE}/IDSWebApp.war.ear/IDSWebApp.war"

        while getopts ":vw:a:uh" cmd_options 
       do case "$cmd_options" in

          v)   OPTION_V=TRUE
	       ;;
          w)   QualifyPath $OPTARG || return $?
               IDSWebApp=${QualifiedPath}
	       ;;
          a)   IDSWebApp_Name=$OPTARG
               APP_ROOT="${WAS_HOME}/installedApps/${WAS_NODE}/${IDSWebApp_Name}.ear/IDSWebApp.war"
	       ;;
          u)   uninstall_only
	       ;;
          h)   printusage
	       ;;
         \?)   printusage
	       ;;

         esac
       done
 
    if [ -z "${IDSWebApp_Name}" ]; then
       IDSWebApp_Name="IDSWebApp.war"
       echo "No Application name supplied. The default name IDSWebApp.war will be used"
    fi


    if [ -z "${IDSWebApp}" ]; then
        IDSWebApp="${WAS_HOME}/installableApps/IDSWebApp.war"
    fi

echo ${IDSWebApp}

return 0
}

#####################################################################
# This function is used to print the help for deploy_IDSWebApp.sh
#


printusage () {

echo "Usage: ./deploy_IDSWebApp.sh [-v] [-h] [-w IDSWebApp.war file] 
                                   [-a Application Name [-u]] 

Deploys IDSWebApp.war to WAS, retaining the configuration settings of the 
currently deployed IDSWebApp, if any.

NOTE:   When deploying the application on WebSphere Application Server v6.0,
        deploy_IDSWebApp.sh must be copied to WAS_HOME/bin.
        When deploying the application on the embedded version of 
        WebSphere Application Server Express, deploy_IDSWebApp.sh must
        be present in <TDS installpath>/idstools
        

{-h     Display Usage. }

{-v     Display the version and date strings for the deploy_IDSWebApp
        script and the application war file.}

{-a     Application Name. Defaults to IDSWebApp.war if not specified. }

{-u     Uninstall a previously existing application.
        -a option should be used to specify the application to uninstall
        If not specified default application IDSWebApp.war would be un-deployed.}

{-w     The fully qualified path of the IDSWebApp.war file to deploy.  }

"

exit 0


}

#####################################################################
# This function is used to only uninstall the already installed IDSWebApp.war application
#

uninstall_only () {
     echo ""
     echo  "You Have chosen to UNDEPLOY IDSWebApp.war" 
     echo ""
     echo "The Configuration files for the current application would be stored in ${WAS_HOME}/temp/uninstall_IDSWebApp.tmp"

    if [ -z "${IDSWebApp_Name}" ]; then
       IDSWebApp_Name="IDSWebApp.war"
       echo  "No Application name supplied. The default application IDSWebApp.war will be un-deployed"
    else
        echo "An Application name has been supplied. The application ${IDSWebApp_Name} will be undeployed"
    fi

    uninstall_CreateTempDirectory || return $?

    uninstall_Backup_IDSWebApp_Configuration || return $? 

    if [ ! -f ${WAS_HOME}/logs/${WAS_SERVER}/${WAS_SERVER}.pid ]; then
            Start_WAS || return $?
    fi

    Uninstall_IDSWebApp 

    exit 0 

}

#####################################################################
#
# Delete ${WAS_HOME}/temp/uninstall_IDSWebApp.tmp directory
#  Used during uninstall_only
#
uninstall_DeleteTempDirectory()
{
    if [ ${DEBUG} = TRUE ]; then
        set -x
    fi

    if [ -d "${UNINSTALL_TEMP}" ]; then
        rm -rf ${UNINSTALL_TEMP}
    fi
}



#####################################################################
#
# Delete ${WAS_HOME}/temp/deploy_IDSWebApp.tmp directory
#
DeleteTempDirectory()
{
    if [ ${DEBUG} = TRUE ]; then
        set -x
    fi
    
    if [ -d "${WAS_TEMP}" ]; then
        rm -rf ${WAS_TEMP}
    fi
}


#####################################################################
#
# Create empty ${WAS_HOME}/temp/uninstall_IDSWebApp.tmp directory
# Used during uninstall_only
#
uninstall_CreateTempDirectory()
{
    if [ ${DEBUG} = TRUE ]; then
        set -x
    fi

    uninstall_DeleteTempDirectory || return $?
    mkdir -p ${UNINSTALL_TEMP} || return $?
}


#####################################################################
#
# Create empty ${WAS_HOME}/temp/deploy_IDSWebApp.tmp directory
#
CreateTempDirectory()
{
    if [ ${DEBUG} = TRUE ]; then
        set -x
    fi
    
    DeleteTempDirectory || return $?
    mkdir -p ${WAS_TEMP} || return $?
}

#####################################################################
#
# Backup CONFIG_FILES (if any) from APP_ROOT to UNINSTALL_TEMP 
# Used during uninstall_only
#
uninstall_Backup_IDSWebApp_Configuration()
{
    if [ ${DEBUG} = TRUE ]; then
        set -x
    fi

    #Set up the environment variables

    if [ ! -d "${APP_ROOT}" ]; then
        return 0
    fi

    for filename in ${CONFIG_FILES}; do
        if [ -f ${APP_ROOT}/${filename} ]; then
            EchoCmd mkdir -p ${UNINSTALL_TEMP}/$(dirname ${filename}) || return 1
            EchoCmd cp ${APP_ROOT}/${filename} ${UNINSTALL_TEMP}/${filename} || return 1
        fi
    done

    return 0
}

#####################################################################
#
# Backup CONFIG_FILES (if any) from APP_ROOT to WAS_TEMP
#
Backup_IDSWebApp_Configuration()
{
    if [ ${DEBUG} = TRUE ]; then
        set -x
    fi
    
    #Set up the environment variables

    if [ ! -d ${APP_ROOT} ]; then
        return 0
    fi

    for filename in ${CONFIG_FILES}; do
        if [ -f ${APP_ROOT}/${filename} ]; then
            EchoCmd mkdir -p ${WAS_TEMP}/$(dirname ${filename}) || return 1
            EchoCmd cp ${APP_ROOT}/${filename} ${WAS_TEMP}/${filename} || return 1
        fi
    done
    
    return 0
}

#####################################################################
#
# Restore CONFIG_FILES (if any) from WAS_TEMP to APP_ROOT
#
Restore_IDSWebApp_Configuration()
{
    if [ ${DEBUG} = TRUE ]; then
        set -x
    fi
    
    for filename in ${CONFIG_FILES}; do
        if [ -f ${WAS_TEMP}/${filename} ]; then
            EchoCmd cp ${WAS_TEMP}/${filename} ${APP_ROOT}/${filename} || return 1
        fi
    done
    
    return 0
}


#####################################################################
#
Start_WAS()
{
    if [ ${DEBUG} = TRUE ]; then
        set -x
    fi
    
    EchoCmd "${WAS_HOME}/bin/startServer.sh" ${WAS_SERVER} || return $?
}

#####################################################################
#
Stop_WAS()
{
    if [ ${DEBUG} = TRUE ]; then
        set -x
    fi

    EchoCmd "${WAS_HOME}/bin/stopServer.sh" ${WAS_SERVER} || return $?
}

#####################################################################
#
Restart_WAS()
{
    if [ ${DEBUG} = TRUE ]; then
        set -x
    fi

    Stop_WAS
    Start_WAS || return $?
}

#####################################################################
#
# Un-deploy existing IDSWebApp.war (if found)...
#
Uninstall_IDSWebApp()
{
    if [ ${DEBUG} = TRUE ]; then
        set -x
    fi

    if [ -d ${APP_ROOT} ]; then
       EchoCmd ${WAS_HOME}/bin/wsadmin.sh '-conntype NONE -c "\$AdminApp uninstall ${IDSWebApp_Name}"' || return $?
    else
       echo ""
       echo "IDSWebApp.war may not be deployed.Please check if the  following application is deployed"
       echo ${APP_ROOT}
    fi
   
    return 0
}

#####################################################################
#
# Deploy new IDSWebApp.war...
#
Install_IDSWebApp()
{
    if [ ${DEBUG} = TRUE ]; then
        set -x
    fi

    EchoCmd ${WAS_HOME}/bin/wsadmin.sh '-conntype NONE -c "\$AdminApp install {'${IDSWebApp}'} {-configroot \"$CONFIG_ROOT\" -node \"$WAS_NODE\" -usedefaultbindings -nodeployejb -appname '${IDSWebApp_Name}' -contextroot \"IDSWebApp\"}"'
    return $?
}

#####################################################################
#
# Display app-version and build-date of IDSWebAppInfo.xml file
#   or localized 'not found' message
#
ShowIDSWebAppInfo()
{
    if [ ${DEBUG} = TRUE ]; then
        set -x
    fi

    if [ -f $1 ]; then
        egrep '(app-version|build-date)' $1
    else
        ls $1 >/dev/null
    fi
}

#####################################################################
#
# "-v"
#
ShowVersionInfo()
{
    if [ ${DEBUG} = TRUE ]; then
        set -x
    fi
    
    # Show script version
    echo ""
    echo "${PATCH_SCRIPT}:"
    echo "    SCRIPT_VER:  ${SCRIPT_VER}"
    echo "    SCRIPT_DATE: ${SCRIPT_DATE}"
    
    # Show version of new IDSWebApp
    echo ""
    echo "${IDSWebApp}:"
    if [ -f ${IDSWebApp} ]; then
        save_PWD=$(pwd)
        cd ${WAS_TEMP}
        ${JAVA_HOME}/bin/jar -xf ${IDSWebApp} ${IDSWebAppInfo}
        cd ${save_PWD}
        ShowIDSWebAppInfo ${WAS_TEMP}/${IDSWebAppInfo}

    else
        ls ${IDSWebApp} >/dev/null
    fi

exit 0

}

#####################################################################
#
# main
#

    InitGlobalVariables $* || return $?
    CreateTempDirectory || return $?
 
    if [ ${OPTION_V} = TRUE ]; then
        ShowVersionInfo
    else
        AssertFileExists ${IDSWebApp} || return $?
        Backup_IDSWebApp_Configuration || return $?
        if [ ! -f ${WAS_HOME}/logs/${WAS_SERVER}/${WAS_SERVER}.pid ]; then
            Start_WAS || return $?
        fi
        Uninstall_IDSWebApp || return $?
        Install_IDSWebApp || return $?
        Restore_IDSWebApp_Configuration || return $?
        Restart_WAS || return $?
    fi
    
    DeleteTempDirectory
    echo "${APP_ROOT}:"
    ShowIDSWebAppInfo ${APP_ROOT}/${IDSWebAppInfo}

